@@ -3,7 +3,7 @@ package Complete::Util;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-01-28'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.609'; # VERSION
+our $VERSION = '0.610'; # VERSION
 
 use 5.010001;
 use strict;
@@ -914,7 +914,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.609 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-28.
+This document describes version 0.610 of Complete::Util (from Perl distribution Complete-Util), released on 2020-01-28.
 
 =head1 DESCRIPTION
 
@@ -944,7 +944,7 @@ Usage:
 
  answer_has_entries($answer) -> int
 
-Check if answer has entries.
+Perinci::Sub::To::POD=HASH(0x55d6eeaf0690).
 
 It is equivalent to:
 
@@ -958,7 +958,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Completion answer structure.
+Perinci::Sub::To::POD=HASH(0x55d6eeaf0690).
 
 =back
 
@@ -972,7 +972,7 @@ Usage:
 
  answer_num_entries($answer) -> int
 
-Get the number of entries in an answer.
+Perinci::Sub::To::POD=HASH(0x55d6eeaf0a68).
 
 It is equivalent to:
 
@@ -986,7 +986,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Completion answer structure.
+Perinci::Sub::To::POD=HASH(0x55d6eeaf0a68).
 
 =back
 
@@ -1000,7 +1000,7 @@ Usage:
 
  arrayify_answer($answer) -> array
 
-Make sure we return completion answer in array form.
+Perinci::Sub::To::POD=HASH(0x55d6eeb54a78).
 
 This is the reverse of C<hashify_answer>. It accepts a hash or an array. If it
 receives a hash, will return its C<words> key.
@@ -1013,7 +1013,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Completion answer structure.
+Perinci::Sub::To::POD=HASH(0x55d6eeb54a78).
 
 =back
 
@@ -1027,7 +1027,7 @@ Usage:
 
  combine_answers($answers, ...) -> hash
 
-Given two or more answers, combine them into one.
+Perinci::Sub::To::POD=HASH(0x55d6eeb55018).
 
 This function is useful if you want to provide a completion answer that is
 gathered from multiple sources. For example, say you are providing completion
@@ -1067,7 +1067,7 @@ Usage:
 
  complete_array_elem(%args) -> array
 
-Complete from array.
+Perinci::Sub::To::POD=HASH(0x55d6eeb55b70).
 
 Try to find completion from an array of strings. Will attempt several methods,
 from the cheapest and most discriminating to the most expensive and least
@@ -1126,7 +1126,7 @@ completed unambiguously into C<unmount>.
 
 =item * B<word>* => I<str> (default: "")
 
-Word to complete.
+Perinci::Sub::To::POD=HASH(0x55d6eeb55b70).
 
 =back
 
@@ -1140,7 +1140,7 @@ Usage:
 
  complete_comma_sep(%args) -> array
 
-Complete a comma-separated list string.
+Perinci::Sub::To::POD=HASH(0x55d6eebba320).
 
 This function is not exported by default, but exportable.
 
@@ -1154,7 +1154,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<remaining> => I<code>
 
-What elements should remain for completion.
+Perinci::Sub::To::POD=HASH(0x55d6eebba320).
 
 This is a more general mechanism if the C<uniq> option does not suffice. Suppose
 you are offering completion for sorting fields. The elements are field names as
@@ -1201,7 +1201,7 @@ completed unambiguously into C<unmount>.
 
 =item * B<uniq> => I<bool>
 
-Whether list should contain unique elements.
+Perinci::Sub::To::POD=HASH(0x55d6eebba320).
 
 When this option is set to true, if the formed list in the current word already
 contains an element, the element will not be offered again as completion answer.
@@ -1223,7 +1223,7 @@ elements.
 
 =item * B<word>* => I<str> (default: "")
 
-Word to complete.
+Perinci::Sub::To::POD=HASH(0x55d6eebba320).
 
 =back
 
@@ -1237,7 +1237,7 @@ Usage:
 
  complete_hash_key(%args) -> array
 
-Complete from hash keys.
+Perinci::Sub::To::POD=HASH(0x55d6eebb6c78).
 
 This function is not exported by default, but exportable.
 
@@ -1253,7 +1253,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<word>* => I<str> (default: "")
 
-Word to complete.
+Perinci::Sub::To::POD=HASH(0x55d6eebb6c78).
 
 =back
 
@@ -1267,7 +1267,7 @@ Usage:
 
  hashify_answer($answer, $meta) -> hash
 
-Make sure we return completion answer in hash form.
+Perinci::Sub::To::POD=HASH(0x55d6eebb7920).
 
 This function accepts a hash or an array. If it receives an array, will convert
 the array into `{words=>$ary}' first to make sure the completion answer is in
@@ -1283,11 +1283,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<$answer>* => I<array|hash>
 
-Completion answer structure.
+Perinci::Sub::To::POD=HASH(0x55d6eebb7920).
 
 =item * B<$meta> => I<hash>
 
-Metadata (extra keys) for the hash.
+Perinci::Sub::To::POD=HASH(0x55d6eebb7920).
 
 =back
 
@@ -1301,7 +1301,7 @@ Usage:
 
  modify_answer(%args) -> undef
 
-Modify answer (add prefix/suffix, etc).
+Perinci::Sub::To::POD=HASH(0x55d6eeb54b20).
 
 This function is not exported by default, but exportable.
 
@@ -1319,30 +1319,7 @@ Arguments ('*' denotes required arguments):
 
 Return value:  (undef)
 
-
-
-=head2 ununiquify_answer
-
-Usage:
-
- ununiquify_answer(%args) -> undef
-
-If answer contains only one item, make it two.
-
-For example, if answer is C<["a"]>, then will make answer become C<["a","a "]>.
-This will prevent shell from automatically adding space.
-
-This function is not exported by default, but exportable.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<answer>* => I<hash|array>
-
-=back
-
-Return value:  (undef)
+=for Pod::Coverage ^(ununiquify_answer)$
 
 =head1 FAQ
 
